@@ -64,6 +64,8 @@ ImageItem::ImageItem(QWidget *parent)
     m_actPrint = nullptr;
     m_pAniWidget = new AnimationWidget(QPixmap(), this);
 
+    m_pixmapstring = ":/images/camera/snapshot.png";
+
     setScaledContents(false);
     setMargin(0);
 
@@ -127,28 +129,31 @@ void ImageItem::updatePicPath(const QString &filePath)
 
     if (fileInfo.suffix() == "webm") {
         m_bVideo = true;
-        video_thumbnailer *m_video_thumbnailer = getLoadLibsInstance()->m_video_thumbnailer();
-        image_data *m_image_data = getLoadLibsInstance()->m_video_thumbnailer_create_image_data();
+        if (DataManager::instance()->encodeEnv() == FFmpeg_Env) {
+            video_thumbnailer *m_video_thumbnailer = getLoadLibsInstance()->m_video_thumbnailer();
+            image_data *m_image_data = getLoadLibsInstance()->m_video_thumbnailer_create_image_data();
 
-        try {
-            //thumber.generateThumbnail(m_path.toUtf8().toStdString(), ThumbnailerImageType::Png, buf);//异常视频这里老崩，给上游提交bug的出处
-            getLoadLibsInstance()->m_video_thumbnailer_generate_thumbnail_to_buffer(m_video_thumbnailer, m_path.toUtf8().data(), m_image_data);
-            auto img = QImage::fromData(m_image_data->image_data_ptr, static_cast<int>(m_image_data->image_data_size), "png");
-            img.scaled(THUMBNAIL_PIXMAP_SIZE, THUMBNAIL_PIXMAP_SIZE);
-            pix = QPixmap::fromImage(img);
-            malloc_trim(0);
-        } catch (...) {
-            qWarning() << "generateThumbnail failed";
+            try {
+                //thumber.generateThumbnail(m_path.toUtf8().toStdString(), ThumbnailerImageType::Png, buf);//异常视频这里老崩，给上游提交bug的出处
+                getLoadLibsInstance()->m_video_thumbnailer_generate_thumbnail_to_buffer(m_video_thumbnailer, m_path.toUtf8().data(), m_image_data);
+                QImage img = QImage::fromData(m_image_data->image_data_ptr, static_cast<int>(m_image_data->image_data_size), "png");
+                img.scaled(THUMBNAIL_PIXMAP_SIZE, THUMBNAIL_PIXMAP_SIZE, Qt::KeepAspectRatioByExpanding);
+                pix = QPixmap::fromImage(img);
+                malloc_trim(0);
+            } catch (...) {
+                qWarning() << "generateThumbnail failed";
+            }
+
+            getLoadLibsInstance()->m_video_thumbnailer_destroy_image_data(m_image_data);
+            getLoadLibsInstance()->m_video_thumbnailer_destroy(m_video_thumbnailer);
+
+            m_image_data = nullptr;
+            m_video_thumbnailer = nullptr;
         }
-
-        getLoadLibsInstance()->m_video_thumbnailer_destroy_image_data(m_image_data);
-        getLoadLibsInstance()->m_video_thumbnailer_destroy(m_video_thumbnailer);
-        m_image_data = nullptr;
-        m_video_thumbnailer = nullptr;
     } else if (fileInfo.suffix() == "jpg") {
         m_bVideo = false;
         QImage img(filePath);
-        img = img.scaled(THUMBNAIL_PIXMAP_SIZE, THUMBNAIL_PIXMAP_SIZE);
+        img = img.scaled(THUMBNAIL_PIXMAP_SIZE, THUMBNAIL_PIXMAP_SIZE, Qt::KeepAspectRatioByExpanding);
         pix = QPixmap::fromImage(img);
         malloc_trim(0);
     } else {
@@ -559,10 +564,6 @@ AnimationWidget::~AnimationWidget()
 
 ImageItem::~ImageItem()
 {
-    QFileInfo fileInfo(m_path);
-    if (fileInfo.suffix() == "webm")
-        DataManager::instance()->setvideoCount(DataManager::instance()->getvideoCount() - 1);
-
     delete m_pAniWidget;
     m_pAniWidget = nullptr;
 
