@@ -30,6 +30,7 @@
 #include "photorecordbtn.h"
 #include "switchcamerabtn.h"
 #include "windowstatethread.h"
+#include "camera.h"
 
 #include <DLabel>
 #include <DApplication>
@@ -64,6 +65,7 @@
 extern "C" {
 #include "encoder.h"
 #include "load_libs.h"
+extern int encodeenv;
 }
 
 using namespace dc;
@@ -81,6 +83,7 @@ const int labelCameraNameWidth = 150;
 const int labelCameraNameHeight = 26;
 const int labelFilterNameWidth = 150;
 const int labelFilterNameHeight = 26;
+const int pathEditWidth = 285;
 
 static void workaround_updateStyle(QWidget *parent, const QString &theme)
 {
@@ -211,21 +214,27 @@ static QWidget *createPicSelectableLineEditOptionHandle(QObject *opt)
     picPathLineEdit->setAccessibleName(OPTION_PIC_SELECTABLE_LINE_EDIT);
     //获取当前设置的照片保存路径
     QString curPicSettingPath = option->value().toString();
-
     if (curPicSettingPath.contains(relativeHomePath))
         curPicSettingPath.replace(0, 1, QDir::homePath());
 
     QDir curPicSettingPathdir(curPicSettingPath);
 
     //路径不存在
-    if (!curPicSettingPathdir.exists())
+    if (!curPicSettingPathdir.exists()) {
         picPathLineEdit->setText(option->defaultValue().toString());//更改文本框为默认路径~/Pictures/Camera
+        curPicSettingPath = option->defaultValue().toString();
+        if (curPicSettingPath.contains(relativeHomePath))
+            curPicSettingPath.replace(0, 1, QDir::homePath());
+    }
     else
         picPathLineEdit->setText(option->value().toString());//更改文本框为设置的路径
 
+    lastPicPath = curPicSettingPath;
+
     QFontMetrics tem_fontmetrics = picPathLineEdit->fontMetrics();
-    QString picStrElideText = ElideText(picPathLineEdit->text(), {285, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
-                                        picPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), 285);
+    QString picStrElideText = ElideText(picPathLineEdit->text(), {pathEditWidth, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
+                                        picPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), pathEditWidth);
+    picPathLineEdit->setText(picStrElideText);
 
     option->connect(picPathLineEdit, &DLineEdit::focusChanged, [ = ](bool on) {
         if (on) {
@@ -243,19 +252,6 @@ static QWidget *createPicSelectableLineEditOptionHandle(QObject *opt)
         }
     });
 
-    picPathLineEdit->setText(picStrElideText);
-
-    if (picStrElideText[0] == '~' && !picStrElideText.compare(option->defaultValue().toString())) {
-        picStrElideText.replace(0, 1, QDir::homePath());
-        lastPicPath = picStrElideText;
-    } else if (picStrElideText[0] == '~' && picStrElideText.compare(option->defaultValue().toString())) {
-        picStrElideText = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation)
-                          + QDir::separator() + "Camera";
-
-        lastPicPath = picStrElideText;
-    } else
-        lastPicPath = picStrElideText;
-
     icon->setIcon(DStyleHelper(icon->style()).standardIcon(DStyle::SP_SelectElement, nullptr));
     icon->setIconSize(QSize(24, 24));
     icon->setFixedSize(41, 37);
@@ -364,10 +360,15 @@ static QWidget *createPicSelectableLineEditOptionHandle(QObject *opt)
 
         if (validate(selectPicSavePath, false)) {
             option->setValue(selectPicSavePath);
-            picPathLineEdit->setText(selectPicSavePath);
-            tmplastpicpath = selectPicSavePath;
+            QFontMetrics tem_fontmetrics = picPathLineEdit->fontMetrics();
+            QString elideText = ElideText(picPathLineEdit->text(), {pathEditWidth, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
+                                                picPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), pathEditWidth);
+            picPathLineEdit->setText(elideText);
         }
 
+        QString qlastPath = Settings::get().getOption("base.save.picdatapath").toString();
+        qDebug() << QString("-----------------qlastPath: %1").arg(qlastPath);
+
         QFileInfo fm(selectPicSavePath);
 
         if ((!fm.isReadable() || !fm.isWritable()) && !selectPicSavePath.isEmpty())
@@ -382,36 +383,38 @@ static QWidget *createPicSelectableLineEditOptionHandle(QObject *opt)
         QString curPicEditStr = picPathLineEdit->text();
         QDir dir(curPicEditStr);
         //获取当前文本框路径
-        QString curPicLineEditPath = ElideText(curPicEditStr, {285, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
-                                               picPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), 285);
+        QString curPicElidePath = ElideText(curPicEditStr, {pathEditWidth, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
+                                               picPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), pathEditWidth);
 
-        if (!validate(picPathLineEdit->text(), false)) {
+        if (!validate(curPicEditStr, false)) {
             QFileInfo fn(dir.path());
 
-            if ((!fn.isReadable() || !fn.isWritable()) && !curPicEditStr.isEmpty())
-                curPicLineEditPath = option->defaultValue().toString();
+            if ((!fn.isReadable() || !fn.isWritable()) && !curPicEditStr.isEmpty()) {
+                // 设置为默认路径
+                curPicEditStr = option->defaultValue().toString();
+                option->setValue(option->defaultValue().toString());
+                curPicElidePath = option->defaultValue().toString();
+            }
         }
 
         if (!picPathLineEdit->lineEdit()->hasFocus()) {
 
             //文本框路径有效
-            if (validate(picPathLineEdit->text(), false)) {
-                option->setValue(curPicLineEditPath);
-                picPathLineEdit->setText(curPicLineEditPath);
-                lastPicPath = curPicLineEditPath;
-            }
-            //路径编辑，但未修改
-            else if (curPicLineEditPath == picStrElideText) {
-                picPathLineEdit->setText(picStrElideText);
+            if (validate(curPicEditStr, false)) {
+                option->setValue(curPicEditStr);
             }
             //文本框路径无效
             else {
-                QString strDefaultPicPath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation)
-                                            + QDir::separator() + "Camera";
-                //设置为默认路径
+                // 设置为默认路径
+                curPicEditStr = option->defaultValue().toString();
+                if (curPicEditStr.front() == '~')
+                    curPicEditStr.replace(0, 1, QDir::homePath());
                 option->setValue(option->defaultValue().toString());
-                picPathLineEdit->setText(option->defaultValue().toString());
+                curPicElidePath = option->defaultValue().toString();
             }
+
+            lastPicPath = curPicEditStr;
+            picPathLineEdit->setText(curPicElidePath);
         }
     });
 
@@ -424,12 +427,13 @@ static QWidget *createPicSelectableLineEditOptionHandle(QObject *opt)
      */
     option->connect(option, &DTK_CORE_NAMESPACE::DSettingsOption::valueChanged, picPathLineEdit,
     [ = ](const QVariant & value) {
-        auto pi = ElideText(value.toString(), {285, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
-                            picPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), 285);
+        auto pi = ElideText(value.toString(), {pathEditWidth, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
+                            picPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), pathEditWidth);
         picPathLineEdit->setText(pi);
-        lastPicPath = pi;
-        option->setValue(pi);
-        qDebug() << "save pic last path:" << pi << endl;
+        qDebug() << "picPathLineEdit text:" << picPathLineEdit->text() << endl;
+        lastPicPath = value.toString();
+        option->setValue(value.toString());
+        qDebug() << "save pic last path:" << value.toString() << endl;
         picPathLineEdit->update();
     });
 
@@ -473,14 +477,21 @@ static QWidget *createVdSelectableLineEditOptionHandle(QObject *opt)
     QDir curVideoSettingPathdir(curVideoSettingPath);
 
     //路径不存在
-    if (!curVideoSettingPathdir.exists())
+    if (!curVideoSettingPathdir.exists()) {
         videoPathLineEdit->setText(option->defaultValue().toString());//更改文本框为默认路径~/Videos/Camera
+        curVideoSettingPath = option->defaultValue().toString();
+        if (curVideoSettingPath.contains(relativeHomePath))
+            curVideoSettingPath.replace(0, 1, QDir::homePath());
+    }
     else
         videoPathLineEdit->setText(option->value().toString());//更改文本框为设置的路径
 
+    lastVideoPath = curVideoSettingPath;
+
     QFontMetrics tem_fontmetrics = videoPathLineEdit->fontMetrics();
-    QString VideoStrElideText = ElideText(videoPathLineEdit->text(), {285, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
-                                          videoPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), 285);
+    QString vdStrElideText = ElideText(videoPathLineEdit->text(), {pathEditWidth, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
+                                          videoPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), pathEditWidth);
+    videoPathLineEdit->setText(vdStrElideText);
 
     option->connect(videoPathLineEdit, &DLineEdit::focusChanged, [ = ](bool on) {
         if (on) {
@@ -498,19 +509,6 @@ static QWidget *createVdSelectableLineEditOptionHandle(QObject *opt)
         }
     });
 
-    videoPathLineEdit->setText(VideoStrElideText);
-
-    if (VideoStrElideText[0] == '~' && !VideoStrElideText.compare(option->defaultValue().toString())) {
-        VideoStrElideText.replace(0, 1, QDir::homePath());
-        lastVideoPath = VideoStrElideText;
-    } else if (VideoStrElideText[0] == '~' && VideoStrElideText.compare(option->defaultValue().toString())) {
-        VideoStrElideText = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation)
-                            + QDir::separator() + "Camera";
-
-        lastVideoPath = VideoStrElideText;
-    } else
-        lastVideoPath = VideoStrElideText;
-
     icon->setIcon(DStyleHelper(icon->style()).standardIcon(DStyle::SP_SelectElement, nullptr));
     icon->setIconSize(QSize(24, 24));
     icon->setFixedSize(41, 37);
@@ -583,17 +581,22 @@ static QWidget *createVdSelectableLineEditOptionHandle(QObject *opt)
      */
     option->connect(icon, &DPushButton::clicked, [ = ]() {
 
-
         QString selectVideoSavePath;
-        QDir dir(lastVideoPath);
+        QString tmplastvdcpath = lastVideoPath;
+
+        if (tmplastvdcpath.contains(relativeHomePath))
+            tmplastvdcpath.replace(0, 1, QDir::homePath());
+
+        QDir dir(tmplastvdcpath);
+
         if (!dir.exists()) {
             //设置文本框为新的路径
-            lastVideoPath = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation)
+            tmplastvdcpath = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation)
                             + QDir::separator() + "Camera";
-            QDir defaultdir(lastVideoPath);
+            QDir defaultdir(tmplastvdcpath);
 
             if (!defaultdir.exists()) {
-                dir.mkdir(lastVideoPath);
+                dir.mkdir(tmplastvdcpath);
             }
             videoPathLineEdit->setText(option->defaultValue().toString());
         }
@@ -602,14 +605,19 @@ static QWidget *createVdSelectableLineEditOptionHandle(QObject *opt)
 #else
         //打开文件夹
         selectVideoSavePath = DFileDialog::getExistingDirectory(nullptr, QObject::tr("Open folder"),
-                                                                lastVideoPath,
+                                                                tmplastvdcpath,
                                                                 DFileDialog::ShowDirsOnly | DFileDialog::DontResolveSymlinks);
+        // 视频保存路径暂时不能设置到smb网盘路径(会卡死在fwrite)，临时处理方案：重置回默认路径
+        if (selectVideoSavePath.contains("/run/user/1000/gvfs/smb-share:server="))
+            selectVideoSavePath = option->defaultValue().toString();
 #endif
 
         if (validate(selectVideoSavePath, false)) {
             option->setValue(selectVideoSavePath);
-            videoPathLineEdit->setText(selectVideoSavePath);
-            lastVideoPath = selectVideoSavePath;
+            QFontMetrics tem_fontmetrics = videoPathLineEdit->fontMetrics();
+            QString elideText = ElideText(videoPathLineEdit->text(), {pathEditWidth, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
+                                                videoPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), pathEditWidth);
+            videoPathLineEdit->setText(elideText);
         }
 
         QFileInfo fm(selectVideoSavePath);
@@ -625,38 +633,45 @@ static QWidget *createVdSelectableLineEditOptionHandle(QObject *opt)
     option->connect(videoPathLineEdit, &DLineEdit::editingFinished, option, [ = ]() {
 
         QString curVideoEditStr = videoPathLineEdit->text();
+
+        // 视频保存路径暂时不能设置到smb网盘路径(会卡死在fwrite)，临时处理方案：重置回默认路径
+        if (curVideoEditStr.contains("/run/user/1000/gvfs/smb-share:server="))
+            curVideoEditStr = option->defaultValue().toString();
+
         QDir dir(curVideoEditStr);
+        // 获取当前文本路径
+        QString curVdElidePath = ElideText(curVideoEditStr, {pathEditWidth, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
+                                                 videoPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), pathEditWidth);
 
-        QString curVideoLineEditPath = ElideText(curVideoEditStr, {285, tem_fontmetrics.height()}, QTextOption::WrapAnywhere,
-                                                 videoPathLineEdit->font(), Qt::ElideMiddle, tem_fontmetrics.height(), 285);
-
-        if (!validate(videoPathLineEdit->text(), false)) {
+        if (!validate(curVideoEditStr, false)) {
             QFileInfo fn(dir.path());
 
-            if ((!fn.isReadable() || !fn.isWritable()) && !curVideoEditStr.isEmpty())
-                curVideoLineEditPath = option->defaultValue().toString();
+            if ((!fn.isReadable() || !fn.isWritable()) && !curVideoEditStr.isEmpty()) {
+                // 设置为默认路径
+                curVideoEditStr = option->defaultValue().toString();
+                option->setValue(option->defaultValue().toString());
+                curVdElidePath = option->defaultValue().toString();
+            }
         }
 
         if (!videoPathLineEdit->lineEdit()->hasFocus()) {
 
             //文本框路径有效
             if (validate(videoPathLineEdit->text(), false)) {
-                option->setValue(videoPathLineEdit->text());
-                videoPathLineEdit->setText(curVideoLineEditPath);
-                lastVideoPath = curVideoEditStr;
-            }
-            //路径编辑，但未修改
-            else if (curVideoLineEditPath == VideoStrElideText) {
-                videoPathLineEdit->setText(VideoStrElideText);
+                option->setValue(curVideoEditStr);
             }
             //文本框路径无效
             else {
-                QString strDefaultVdPath = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation)
-                                           + QDir::separator() + "Camera";
-                //设置为默认路径
+                // 设置为默认路径
+                curVideoEditStr = option->defaultValue().toString();
+                if (curVideoEditStr.front() == '~')
+                    curVideoEditStr.replace(0, 1, QDir::homePath());
                 option->setValue(option->defaultValue().toString());
-                videoPathLineEdit->setText(option->defaultValue().toString());
+                curVdElidePath = option->defaultValue().toString();
             }
+
+            lastVideoPath = curVideoEditStr;
+            videoPathLineEdit->setText(curVdElidePath);
         }
     });
 
@@ -669,14 +684,14 @@ static QWidget *createVdSelectableLineEditOptionHandle(QObject *opt)
      */
     option->connect(option, &DTK_CORE_NAMESPACE::DSettingsOption::valueChanged, videoPathLineEdit,
     [ = ](const QVariant & value) {
-        auto pi = ElideText(value.toString(), {285, tem_fontmetrics.height()},
+        auto pi = ElideText(value.toString(), {pathEditWidth, tem_fontmetrics.height()},
                             QTextOption::WrapAnywhere, videoPathLineEdit->font(), Qt::ElideMiddle,
-                            tem_fontmetrics.height(), 285);
-
+                            tem_fontmetrics.height(), pathEditWidth);
         videoPathLineEdit->setText(pi);
-        lastVideoPath = pi;
-        option->setValue(pi);
-
+        qDebug() << "picPathLineEdit text:" << videoPathLineEdit->text() << endl;
+        lastVideoPath = value.toString();
+        option->setValue(value.toString());
+        qDebug() << "save video last path:" << value.toString() << endl;
         videoPathLineEdit->update();
     });
 
@@ -699,6 +714,12 @@ QString CMainWindow::lastOpenedPath(QStandardPaths::StandardLocation standard)
                        + QDir::separator() + "Camera";
     }
 
+    // 包含主目录相对路径，QDir不能识别，必须转为绝对路径
+    QString relativeHomePath = QString("~") + QDir::separator();
+    if (lastPath.contains(relativeHomePath)) {
+        lastPath.replace(0, 1, QDir::homePath());
+    }
+
     QDir lastDir(lastPath);
     if (lastPath.isEmpty() || !lastDir.exists()) {
         if (standard == QStandardPaths::MoviesLocation) {
@@ -781,8 +802,10 @@ QString CMainWindow::libPath(const QString &strlib)
         return strlib;
 
     list.sort();
-    Q_ASSERT(list.size() > 0);
-    return list.last();
+    if (list.size() > 0)
+        return list.last();
+
+    return "";
 }
 
 void CMainWindow::reflushSnapshotLabel()
@@ -929,8 +952,6 @@ void CMainWindow::initTabOrder()
     setTabOrder(m_windowMinBtn, m_windowMaxBtn);
     setTabOrder(m_windowMaxBtn, m_windowCloseBtn);
     setTabOrder(m_windowCloseBtn, m_takePhotoSettingArea);
-
-    m_pTitlebar->titlebar()->setFocusPolicy(Qt::NoFocus);
 }
 
 void CMainWindow::initEventFilter()
@@ -1046,7 +1067,8 @@ void CMainWindow::initShortcut()
         else if (m_snapshotLabel == focuswidget)
             m_snapshotLabel->openFile();
         else if (m_cameraSwitchBtn == focuswidget)
-            m_videoPre->onChangeDev();
+            //m_videoPre->onChangeDev();
+            m_cameraSwitchBtn->clicked();
         else
             return;
     });
@@ -1067,6 +1089,8 @@ void CMainWindow::settingDialog()
 
     auto resolutionmodeFamily = Settings::get().settings()->option("outsetting.resolutionsetting.resolution");
 
+
+
     if (get_v4l2_device_handler() != nullptr) {
         //格式索引
         int format_index = v4l2core_get_frame_format_index(
@@ -1154,14 +1178,28 @@ void CMainWindow::settingDialog()
         }
     } else {
         //初始化分辨率字符串表
+        int defres = 0;
         QStringList resolutionDatabase = resolutionmodeFamily->data("items").toStringList();
+        if (DataManager::instance()->encodeEnv() == QCamera_Env && !Camera::instance()->getSupportResolutions().isEmpty()) {
+            resolutionDatabase = Camera::instance()->getSupportResolutions();
 
-        if (resolutionDatabase.size() > 0)
-            resolutionmodeFamily->data("items").clear();
+            for (int i = 0; i < resolutionDatabase.size(); i++) {
+                QStringList resolutiontemp = resolutionDatabase[i].split("x");
 
-        resolutionDatabase.clear();
-        resolutionDatabase.append(QString(tr("None")));
-        Settings::get().settings()->setOption(QString("outsetting.resolutionsetting.resolution"), 0);
+                if ((Camera::instance()->getCameraResolution().width() == resolutiontemp[0].toInt()) &&
+                        Camera::instance()->getCameraResolution().height() == resolutiontemp[1].toInt()) {
+                    defres = i; //设置分辨率下拉菜单当前索引
+                    break;
+                }
+            }
+        } else {
+            if (resolutionDatabase.size() > 0)
+                resolutionmodeFamily->data("items").clear();
+
+            resolutionDatabase.clear();
+            resolutionDatabase.append(QString(tr("None")));
+        }
+        Settings::get().settings()->setOption(QString("outsetting.resolutionsetting.resolution"), defres);
         resolutionmodeFamily->setData("items", resolutionDatabase);
     }
     m_SetDialog->setProperty("_d_QSSThemename", "dark");
@@ -1183,6 +1221,7 @@ void CMainWindow::settingDialogDel()
 
 void CMainWindow::loadAfterShow()
 {
+    encodeenv = DataManager::instance()->encodeEnv();
     initDynamicLibPath();
     //该方法导致键盘可用性降低，调试时无法使用、触摸屏无法唤起多次右键菜单，改用备用方案
     initUI();
@@ -1209,8 +1248,12 @@ void CMainWindow::loadAfterShow()
 
     connect(m_devnumMonitor, SIGNAL(seltBtnStateEnable()), this, SLOT(setSelBtnShow()));//显示切换按钮
     connect(m_devnumMonitor, SIGNAL(seltBtnStateDisable()), this, SLOT(setSelBtnHide()));//多设备信号
-    connect(m_devnumMonitor, SIGNAL(existDevice()), m_videoPre, SLOT(onRestartDevices()));//重启设备
-    connect(m_devnumMonitor, SIGNAL(noDeviceFound()), m_videoPre, SLOT(onRestartDevices()));//重启设备
+    if(DataManager::instance()->encodeEnv() != QCamera_Env) {
+        connect(m_devnumMonitor, SIGNAL(existDevice()), m_videoPre, SLOT(onRestartDevices()));//重启设备
+        connect(m_devnumMonitor, SIGNAL(noDeviceFound()), m_videoPre, SLOT(onRestartDevices()));//重启设备
+    } else if (DataManager::instance()->encodeEnv() == QCamera_Env) {
+        initCameraConnection();
+    }
 
     m_videoPre->delayInit();
     m_videoPre->setFilterType(filter_Normal);
@@ -1264,8 +1307,14 @@ void CMainWindow::stopCancelContinuousRecording(bool bTrue)
 void CMainWindow::onDirectoryChanged(const QString &filePath)
 {
     Q_UNUSED(filePath);
+    // 转为绝对路径进行比较
+    QString relativeHomePath = QString("~") + QDir::separator();
     QString videoPath = Settings::get().getOption("base.save.vddatapath").toString();
     QString picPath = Settings::get().getOption("base.save.picdatapath").toString();
+    if (videoPath.contains(relativeHomePath))
+            videoPath.replace(0, 1, QDir::homePath());
+    if (picPath.contains(relativeHomePath))
+        picPath.replace(0, 1, QDir::homePath());
     QDir  dir(videoPath);
     if (!dir.exists()) {
         QString videoDefaultPath = lastOpenedPath(QStandardPaths::MoviesLocation);
@@ -1640,6 +1689,7 @@ void CMainWindow::initUI()
     connect(m_takePhotoSettingArea, &takePhotoSettingAreaWidget::sngSetFlashlight, this, &CMainWindow::onSetFlash);
     connect(m_takePhotoSettingArea, &takePhotoSettingAreaWidget::sngFilterChanged, this, &CMainWindow::onFilterChanged);
     connect(m_takePhotoSettingArea, &takePhotoSettingAreaWidget::sngShowFilterName, this, &CMainWindow::onShowFilterName);
+    connect(m_takePhotoSettingArea, &takePhotoSettingAreaWidget::sigFilterGroupDisplay, m_videoPre, &videowidget::onFilterDisplayChanged);
     connect(m_takePhotoSettingArea, &takePhotoSettingAreaWidget::sngSetFilterName, this, &CMainWindow::onSetFilterName);
     connect(m_takePhotoSettingArea, &takePhotoSettingAreaWidget::sigExposureChanged, m_videoPre, &videowidget::onExposureChanged);
     connect(&dc::Settings::get(), SIGNAL(flashLightChanged(bool)), this, SLOT(onSetFlash(bool)));
@@ -1835,6 +1885,34 @@ void CMainWindow::initConnection()
                                          "org.freedesktop.login1.Manager", "PrepareForShutdown", this, SLOT(stopCancelContinuousRecording(bool)));
 }
 
+void CMainWindow::initCameraConnection()
+{
+    connect(m_devnumMonitor, &DevNumMonitor::existDevice, Camera::instance(), &Camera::refreshCamera);
+    connect(Camera::instance(), SIGNAL(cameraSwitched(const QString &)), this, SLOT(onSwitchCameraSuccess(const QString &)));
+    // 摄像头重连，刷新设置页分辨率下拉框内容
+    connect(Camera::instance(), SIGNAL(cameraDevRestarted()), &Settings::get(), SLOT(setNewResolutionList()));
+    // 当前无摄像头设备，给出无摄像头提示
+    connect(m_devnumMonitor, &DevNumMonitor::noDeviceFound, this, [=](){
+        Camera::instance()->stopCamera();
+        DataManager::instance()->setdevStatus(NOCAM);
+        m_videoPre->showNocam();
+        QImage image;
+        m_takePhotoSettingArea->onUpdateFilterImage(&image);
+    });
+    // 当前设备断开连接，给出无摄像头提示
+    connect(Camera::instance(), &Camera::currentCameraDisConnected, this, [=](){
+        Camera::instance()->stopCamera();
+        DataManager::instance()->setdevStatus(NOCAM);
+        m_videoPre->showNocam();
+        QImage image;
+        m_takePhotoSettingArea->onUpdateFilterImage(&image);
+    });
+    connect(Camera::instance(), &Camera::cameraCannotUsed, this, [=](){
+        DataManager::instance()->setdevStatus(CAM_CANNOT_USE);
+        m_videoPre->showCamUsed();
+    });
+}
+
 void CMainWindow::initRightButtons()
 {
     m_cameraSwitchBtn = new SwitchCameraBtn(this);
@@ -1863,7 +1941,10 @@ void CMainWindow::initRightButtons()
     m_snapshotLabel->setObjectName(THUMBNAIL_PREVIEW);
     m_snapshotLabel->setAccessibleName(THUMBNAIL_PREVIEW);
 
-    connect(m_cameraSwitchBtn, SIGNAL(clicked()), m_videoPre, SLOT(onChangeDev()));
+    if (DataManager::instance()->encodeEnv() != QCamera_Env)
+        connect(m_cameraSwitchBtn, SIGNAL(clicked()), m_videoPre, SLOT(onChangeDev()));
+    else
+        connect(m_cameraSwitchBtn, SIGNAL(clicked()), Camera::instance(), SLOT(switchCamera()));
     connect(m_modeSwitchBox, &RollingBox::currentValueChanged, this, &CMainWindow::onModeSwitchBoxValueChanged);
     connect(m_photoRecordBtn, SIGNAL(clicked()), this, SLOT(onPhotoRecordBtnClked()));
     connect(m_snapshotLabel, SIGNAL(trashFile(const QString &)), SLOT(onTrashFile(const QString &)));
