@@ -28,6 +28,8 @@
 #include <QMutex>
 #include <QWaitCondition>
 
+#include "datamanager.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -100,13 +102,28 @@ public:
         m_bPhoto = bPhoto;
     }
 
+    /**
+     * @brief setRecording 设置视频是否正在录制
+     * @param bStatus  true 录制中 false 未录制
+     */
+    void setRecording(bool bRecording) {
+        m_bRecording = bRecording;
+    }
+
+    /**
+     * @brief setFilterGroupState 设置滤镜按钮组展开状态
+     * @param bDisplay  true 展开 false 关闭
+     */
+    void setFilterGroupState(bool bDisplay){
+        m_filtersGroupDislay = bDisplay;
+    }
+
 protected:
     /**
      * @brief run 运行线程
      */
     void run();
 
-
 signals:
     /**
      * @brief SendMajorImageProcessing 向预览界面发送帧数据  mips平台、wayland下使用该接口
@@ -140,8 +157,16 @@ signals:
      * @param width
      */
     void sigRenderYuv(bool);
+
 #endif
 
+    /**
+     * @brief sigRecordFrame 发送GStreamer视频帧写入信号
+     * @param rgb  rgb24帧数据
+     * @param size yuv数据大小
+     */
+    void sigRecordFrame(uchar *rgb, uint size);
+
     /**
      * @brief reachMaxDelayedFrames 到达最大延迟信号
      */
@@ -156,6 +181,9 @@ public:
 private:
     void ImageHorizontalMirror(const uint8_t* src, uint8_t* dst, int width, int height);
 
+public slots:
+    void processingImage(QImage&);
+
 private:
     int               m_result;
     uint              m_nVdWidth;
@@ -165,14 +193,19 @@ private:
     QAtomicInt        m_stopped;
     v4l2_dev_t        *m_videoDevice;
     v4l2_frame_buff_t *m_frame;
-    uint8_t           *m_yuvPtr;
+    uint8_t           *m_yuvPtr;// yu12视频帧数据
+    uint8_t           *m_rgbPtr;// rgb视频帧数据
 
     bool              m_bPhoto = true; //相机当前状态，默认为拍照状态
+    bool              m_bRecording;//是否处理视频录制状态 GStreamer环境下使用
     bool              m_bHorizontalMirror;   //水平镜像
+    EncodeEnv         m_eEncodeEnv;          //编码环境
     int               m_exposure = 0;
+    bool              m_filtersGroupDislay = false;//滤镜按钮组是否显示
 
-    QImage             m_Img;   //mips、wayland下使用该变量
-    QImage             m_filterImg; //滤镜预览类使用 大小40*40
+    QImage            m_Img;   //mips、wayland下使用该变量
+    QImage            m_filterImg; //滤镜预览类使用 大小40*40
+    QImage            m_jpgImage; // 从v4l2获取的jpg格式的视频帧图片
 
 };
 
