@@ -739,6 +739,7 @@ void takePhotoSettingAreaWidget::showFilters(bool bShow, bool isShortcut)
         connect(pPosGroup, &QPropertyAnimation::finished, this, [=]{
             for (auto pBtn : m_filterPreviewBtnList) {
                 pBtn->update();
+                pBtn->clearFocus();
             }
         });
 
@@ -887,11 +888,13 @@ void takePhotoSettingAreaWidget::filtersUnfoldBtnClicked(bool isShortcut)
     closeAllGroup();
     m_filtersGroupDislay = true;
     showFilters(true, isShortcut);
+    emit sigFilterGroupDisplay(true);
 }
 
 void takePhotoSettingAreaWidget::filtersFoldBtnClicked(bool isShortcut)
 {
     showFilters(false, isShortcut);
+    emit sigFilterGroupDisplay(false);
 }
 
 void takePhotoSettingAreaWidget::hideAll()
